#!/bin/bash

# Funkce pro klonování git repo, pokud neexistuje
clone_repo() {
  local repo_url=$1
  local target_dir=$2
  if [ ! -d "$target_dir" ]; then
    git clone "$repo_url" "$target_dir"
  else
    echo "Adresář $target_dir již existuje. Přeskakuji klonování $repo_url."
  fi
}

# Kontrola, zda je Oh-My-Zsh nainstalovaný
if [ ! -d "$HOME/.oh-my-zsh" ]; then
  echo "Oh-My-Zsh není nainstalován. Instaluji Oh-My-Zsh..."
  sh -c "$(curl -fsSL https://raw.github.com/ohmyzsh/ohmyzsh/master/tools/install.sh)"
else
  echo "Oh-My-Zsh je již nainstalován."
fi

# Instalace Powerlevel10k
clone_repo "https://github.com/romkatv/powerlevel10k.git" "${ZSH_CUSTOM:-$HOME/.oh-my-zsh/custom}/themes/powerlevel10k"

# Instalace pluginů
clone_repo "https://github.com/zsh-users/zsh-autosuggestions" "${ZSH_CUSTOM:-$HOME/.oh-my-zsh/custom}/plugins/zsh-autosuggestions"
clone_repo "https://github.com/zsh-users/zsh-syntax-highlighting.git" "${ZSH_CUSTOM:-$HOME/.oh-my-zsh/custom}/plugins/zsh-syntax-highlighting"
clone_repo "https://github.com/zsh-users/zsh-completions" "${ZSH_CUSTOM:-$HOME/.oh-my-zsh/custom}/plugins/zsh-completions"
clone_repo "https://github.com/zsh-users/zsh-history-substring-search" "${ZSH_CUSTOM:-$HOME/.oh-my-zsh/custom}/plugins/zsh-history-substring-search"
clone_repo "https://github.com/hlissner/zsh-autopair" "${ZSH_CUSTOM:-$HOME/.oh-my-zsh/custom}/plugins/zsh-autopair"
clone_repo "https://github.com/rupa/z.git" "${ZSH_CUSTOM:-$HOME/.oh-my-zsh/custom}/plugins/z"

# Instalace Nerd Fonts
if ! fc-list | grep -qi "Nerd Font"; then
  echo "Instaluji Nerd Fonts..."
  sudo pacman -S --noconfirm nerd-fonts-complete
else
  echo "Nerd Fonts jsou již nainstalovány."
fi

# Aktualizace ~/.zshrc
ZSHRC="$HOME/.zshrc"
if [ ! -f "$ZSHRC" ]; then
  touch "$ZSHRC"
fi

# Nastavení Powerlevel10k jako téma
if ! grep -q '^ZSH_THEME="powerlevel10k/powerlevel10k"$' "$ZSHRC"; then
  sed -i 's/^ZSH_THEME=.*/ZSH_THEME="powerlevel10k\/powerlevel10k"/' "$ZSHRC"
fi

# Přidání pluginů do .zshrc
if ! grep -q '^plugins=' "$ZSHRC"; then
  echo 'plugins=(git zsh-autosuggestions zsh-syntax-highlighting zsh-completions zsh-history-substring-search zsh-autopair z)' >> "$ZSHRC"
else
  sed -i 's/^plugins=.*/plugins=(git zsh-autosuggestions zsh-syntax-highlighting zsh-completions zsh-history-substring-search zsh-autopair z)/' "$ZSHRC"
fi

# Zajištění, že Powerlevel10k a pluginy budou načteny
if ! grep -q "source $ZSH/oh-my-zsh.sh" "$ZSHRC"; then
  echo 'source $ZSH/oh-my-zsh.sh' >> "$ZSHRC"
fi

# Načtení změn
source "$ZSHRC"

# Konfigurace Powerlevel10k
echo "Spuštění konfigurace Powerlevel10k..."
p10k configure

echo "Instalace a konfigurace dokončena. Užijte si svůj nový Zsh!"
